@@ -9,18 +9,27 @@ class LinearContrast(BaseImageAugmentation):
     Stream processor which applies linear contrast to images.
     """
 
-    alpha_from = TypedOption(
+    alpha_from: float = TypedOption(
         "-f", "--from-alpha",
         type=float,
         help="the minimum alpha to apply to the images"
     )
 
-    alpha_to = TypedOption(
+    alpha_to: float = TypedOption(
         "-t", "--to-alpha",
         type=float,
         help="the maximum alpha to apply to the images"
     )
 
+    def _default_suffix(self):
+        """
+        Returns the default suffix to use for images when using "add" rather than "replace" as mode.
+
+        :return: the default suffix
+        :rtype: str
+        """
+        return "-contrasted"
+
     def _can_augment(self):
         """
         Checks whether augmentation can take place.
